# coding: utf-8

"""
    Prowlarr

    Prowlarr API docs  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TvSearchParam(str, Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """

    Q = 'q'
    SEASON = 'season'
    EP = 'ep'
    IMDB_ID = 'imdbId'
    TVDB_ID = 'tvdbId'
    R_ID = 'rId'
    TV_MAZE_ID = 'tvMazeId'
    TRAKT_ID = 'traktId'
    TMDB_ID = 'tmdbId'
    DOUBAN_ID = 'doubanId'
    GENRE = 'genre'
    YEAR = 'year'

